
# Mark this directory as a package

__all__ = ['publish', 'compile_template', 'imphooks', 'session', 'errors']

# These functions are really handy, make them easy to get at.
from quixote.publish import get_publisher, get_request, get_session, get_user




_q_exports = ["other"]

from quixote.errors import TraversalError

from quixote.demo.pages import _q_index

def other(request):
    return "Handled by a Python function."

def fact(n):
    f = n*1L
    while n > 1:
        f *= n
        n -= 1
    return f

class IntegerUI:

    _q_exports = ["index", "factorial"]

    def __init__(self, request, component):
        try:
            self.n = int(component)
        except ValueError, exc:
            raise TraversalError(request.get_path(), str(exc))
    
    def factorial(self, request):
        return "%d! = %d" % (self.n, fact(self.n))
        
    def _q_index(self, request):
        return """\
You have selected the integer %d.<p>

Let's compute its <a href="factorial">factorial</a> (%d!)<p>
""" % (self.n, self.n)

def _q_getname(request, component):
    return IntegerUI(request, component)



"""quixote.init

Stuff for setting up Quixote prior to entering the main loop.

Note that if you're using ZODB, you must import ZODB before installing
Quixote's import hooks -- we're not sure why this is, but it is.  This
applies to 'init_quixote()' and 'install_imphooks()'.
"""

# created 2000/08/01, GPW

__revision__ = "$Id: init.py,v 1.7 2001/05/29 20:19:35 gward Exp $"

def init_quixote ():
    install_imphooks()

def install_imphooks ():
    from quixote import imphooks
    imphooks.install()
